@@ -163,12 +163,12 @@ void    mail_stream_cleanup(MAIL_STREAM *info)
 
 static int stamp_stream(VSTREAM *fp, time_t when)
 {
-    struct timeval tv;
+    struct timeval tv[2];
 
     if (when != 0) {
-	tv.tv_sec = when;
-	tv.tv_usec = 0;
-	return (futimesat(vstream_fileno(fp), (char *) 0, &tv));
+	tv[0].tv_sec = tv[1].tv_sec = when;
+	tv[0].tv_usec = tv[1].tv_usec = 0;
+	return (futimesat(vstream_fileno(fp), (char *) 0, tv));
     } else {
 	return (futimesat(vstream_fileno(fp), (char *) 0, (struct timeval *) 0));
     }
@@ -181,12 +181,12 @@ static int stamp_stream(VSTREAM *fp, time_t when)
 
 static int stamp_stream(VSTREAM *fp, time_t when)
 {
-    struct timeval tv;
+    struct timeval tv[2];
 
     if (when != 0) {
-	tv.tv_sec = when;
-	tv.tv_usec = 0;
-	return (futimes(vstream_fileno(fp), &tv));
+	tv[0].tv_sec = tv[1].tv_sec = when;
+	tv[0].tv_usec = tv[1].tv_usec = 0;
+	return (futimes(vstream_fileno(fp), tv));
     } else {
 	return (futimes(vstream_fileno(fp), (struct timeval *) 0));
     }
